class immutabledict:
    def __len__(self) -> int: ...
    def __getitem__(self, __item): ...
    def __iter__(self): ...
    def union(self, **kwargs): ...
    def merge_with(self, *args): ...
    def keys(self): ...
    def __contains__(self, __item): ...
    def items(self): ...
    def values(self): ...
    def get(self, __key, __default=...): ...
    def __reduce__(self): ...
