from typing import Any

EMPTY_ANNOTATIONS: Any

class SupportsAnnotations: ...
class SupportsCloneAnnotations(SupportsAnnotations): ...
class SupportsWrappingAnnotations(SupportsAnnotations): ...

class Annotated:
    def __new__(cls, *args): ...
    __dict__: Any
    def __init__(self, element, values) -> None: ...
    def __reduce__(self): ...
    def __hash__(self): ...
    def __eq__(self, other): ...
    @property
    def entity_namespace(self): ...

annotated_classes: Any
