from typing import Any

def compiles(class_, *specs): ...
def deregister(class_) -> None: ...

class _dispatcher:
    specs: Any
    def __init__(self) -> None: ...
    def __call__(self, element, compiler, **kw): ...
