from .. import exc as sa_exc

class SATestSuiteWarning(sa_exc.SAWarning): ...

def warn_test_suite(message) -> None: ...
def setup_filters() -> None: ...
def assert_warnings(fn, warning_msgs, regex: bool = ...): ...
